@@ -19,6 +19,7 @@ import rgallery.models as mymodels
 from datetime import datetime
 from pprint import pprint
 
+from sorl.thumbnail import get_thumbnail
 from dropbox import client, rest, session
 
 
@@ -209,6 +210,11 @@ class Command(BaseCommand):
                         im.save()
                         im2.save(destdir + '/' + nombre_imagen_repe)
                         print "      Duplicada en disco, cambiado nombre a: %s" % nombre_imagen_repe
+
+                    print "Haciendo thumb 200x200"
+                    im = get_thumbnail(im, "200x200")
+                    print "Haciendo thumb 800x800"
+                    im = get_thumbnail(im, "800x800")
                 total += 1
             #print "-"*80
 
@@ -218,3 +224,11 @@ class Command(BaseCommand):
         print "[***] Repetidas en db: %s" % repetidas
         print "[***] Repetidas en disco: %s" % descargadas
         print "[***] Total: %s" % total
+
+        print "[***] Haciendo thumbs (200x200 y 800x00) de las que no tienen todavía"
+        allphotos = mymodels.Photo.objects.all()
+        for p in allphotos:
+            im = get_thumbnail(p, "200x200")
+            im = get_thumbnail(p, "800x800")
+        print "[***] Hecho."
+
